@@ -20,7 +20,7 @@
 #ifndef KPTFACTORY_H
 #define KPTFACTORY_H
 
-#include "kplato_export.h"
+#include "plan_export.h"
 
 #include <kpluginfactory.h>
 
@@ -30,14 +30,14 @@ class KoComponentData;
 namespace KPlato
 {
 
-class KPLATO_EXPORT Factory : public KPluginFactory
+class PLAN_EXPORT Factory : public KPluginFactory
 {
     Q_OBJECT
 public:
     explicit Factory();
-    ~Factory();
+    ~Factory() override;
 
-    virtual QObject* create(const char* iface, QWidget* parentWidget, QObject *parent, const QVariantList& args, const QString& keyword);
+    QObject* create(const char* iface, QWidget* parentWidget, QObject *parent, const QVariantList& args, const QString& keyword) override;
 
     static const KoComponentData &global();
 
