@@ -31,7 +31,6 @@
 #include "kptconfig.h"
 #include "kptwbsdefinition.h"
 #include "kptxmlloaderobject.h"
-#include "about/aboutpage.h"
 
 #include "KoDocument.h"
 
@@ -130,8 +129,6 @@ public:
     bool insertProject(Project &project, Node *parent, Node *after);
     bool mergeResources(Project &project);
 
-    KPlatoAboutPage &aboutPage() { return m_aboutPage; }
-
     bool extractFiles(KoStore *store, Package *package);
     bool extractFile(KoStore *store, Package *package, const Document *doc);
 
@@ -254,8 +251,6 @@ private:
     QList<QUrl> m_skipUrls;
     QMap<QDateTime, Project*> m_mergedPackages;
 
-    KPlatoAboutPage m_aboutPage;
-
     QDomDocument m_reports;
 
     bool m_viewlistModified;
