@@ -20,7 +20,7 @@
 #ifndef KPTMYCOMBOBOX_P_H
 #define KPTMYCOMBOBOX_P_H
 
-#include "kplato_export.h"
+#include "plan_export.h"
 
 #include <kcombobox.h>
 
@@ -32,7 +32,7 @@ class MyComboBox : public KComboBox
 public:
     explicit MyComboBox(QWidget *parent = 0) : KComboBox(parent) {}
 
-    void emitActivated( int i ) { emit activated( i ); }
+    void emitActivated(int i) { emit activated(i); }
 
 };
 
