@@ -32,8 +32,8 @@ class PrintingControlPrivate : public QObject
 {
     Q_OBJECT
 public:
-    PrintingControlPrivate( PrintingDialog *job, QPrintDialog *dia );
-    ~PrintingControlPrivate() {}
+    PrintingControlPrivate(PrintingDialog *job, QPrintDialog *dia);
+    ~PrintingControlPrivate() override {}
 public Q_SLOTS:
     void slotChanged();
 private:
