@@ -17,13 +17,14 @@
 */
 
 
+// clazy:excludeall=qstring-arg
 #include "kptpackage.h"
 
 using namespace KPlato;
 
 Package::Package()
-    : task( 0 ),
-    toTask( 0 )
+    : task(0)
+    , toTask(0)
 {
 }
 
