@@ -643,6 +643,17 @@ Duration Schedule::plannedEffortTo(const Resource *resource, const QDate &date,
     return eff;
 }
 
+Duration Schedule::plannedEffortTo(const QDateTime &time, EffortCostCalculationType type) const
+{
+    //debugPlan;
+    Duration eff;
+    QListIterator<Appointment*> it(m_appointments);
+    while (it.hasNext()) {
+        eff += it.next() ->plannedEffortTo(time, type);
+    }
+    return eff;
+}
+
 EffortCost Schedule::plannedCost(EffortCostCalculationType type) const
 {
     //debugPlan;
@@ -1599,7 +1610,8 @@ ScheduleManager::ScheduleManager(Project &project, const QString name)
     m_scheduling(false),
     m_progress(0),
     m_maxprogress(0),
-    m_expected(0),
+    m_expected(nullptr),
+    m_calculationresult(0),
     m_schedulingMode(false)
 {
     //debugPlan<<name;
