@@ -20,6 +20,7 @@ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
 
+// clazy:excludeall=qstring-arg
 #include "KoFilterManager.h"
 #include "KoFilterManager_p.h"
 #include "KoDocument.h"
@@ -52,6 +53,7 @@ KoFilterManager::KoFilterManager(KoDocument* document,
         m_document(document), m_parentChain(0), m_graph(""),
         d(new Private())
 {
+    Q_UNUSED(progressUpdater)
     d->batch = false;
 }
 
@@ -453,7 +455,7 @@ QStringList KoFilterManager::mimeFilter()
     QHash<QByteArray, Vertex*> vertices;
     buildGraph(vertices, KoFilterManager::Import);
 
-    QList<KoDocumentEntry> parts(KoDocumentEntry::query( QString()));
+    QList<KoDocumentEntry> parts(KoDocumentEntry::query(QString()));
     QList<KoDocumentEntry>::ConstIterator partIt(parts.constBegin());
     QList<KoDocumentEntry>::ConstIterator partEnd(parts.constEnd());
 
@@ -502,12 +504,12 @@ bool KoFilterManager::filterAvailable(KoFilterEntry::Ptr entry)
 #if 1
         return true;
 #else
-    //kDebug( 30500 ) <<"Checking whether" << entry->service()->name() <<" applies.";
+    //kDebug(30500) <<"Checking whether" << entry->service()->name() <<" applies.";
     // generate some "unique" key
     QString key = entry->service()->name() + " - " + entry->service()->library();
 
     if (!m_filterAvailable.contains(key)) {
-        //kDebug( 30500 ) <<"Not cached, checking...";
+        //kDebug(30500) <<"Not cached, checking...";
 
         KLibrary library(QFile::encodeName(entry->service()->library()));
         if (library.fileName().isEmpty()) {
