@@ -64,7 +64,7 @@ public:
         //if (role == Qt::DisplayRole) debugPlan<<index.row()<<","<<index.column()<<"("<<columnCount()<<")"<<v;
         return v;
     }
-    void setRejectColumns(const QList<int> &columns) { m_rejects = columns; invalidateFilter(); }
+    void setRejectColumns(const QList<int> &columns) { beginResetModel(); m_rejects = columns; endResetModel(); }
     QList<int> rejectColumns() const { return m_rejects; }
     void setZeroColumns(const QList<int> &columns) { m_zerocolumns = columns; }
     QList<int> zeroColumns() const { return m_zerocolumns; }
@@ -131,6 +131,8 @@ public:
 
     void setLocalizeValues(bool on);
 
+    int rowForDate(const QDate &date) const;
+
 public Q_SLOTS:
     void setScheduleManager(KPlato::ScheduleManager *sm) override;
     void slotNodeRemoved(KPlato::Node *node);
@@ -159,19 +161,38 @@ protected:
     bool m_localizeValues;
 };
 
-class PLANMODELS_EXPORT PerformanceDataCurrentDateModel : public ChartItemModel
+class PLANMODELS_EXPORT PerformanceDataCurrentDateModel : public QAbstractProxyModel
 {
     Q_OBJECT
 public:
-    explicit PerformanceDataCurrentDateModel(QObject *parent);
+    explicit PerformanceDataCurrentDateModel(QObject *parent = nullptr);
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex &idx) const override;
     QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &proxyIndex, int role = Qt::DisplayRole) const override;
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
-    QModelIndex mapIndex(const QModelIndex &idx) const;
+    QModelIndex mapToSource(const QModelIndex &idx) const override;
+    QModelIndex mapFromSource(const QModelIndex &idx) const override;
+
+    Project *project() const;
+    ScheduleManager *scheduleManager() const;
+    bool isReadWrite() const;
+
+    void setNodes(const QList<Node*> &nodes);
+    void addNode(Node *node);
+    void clearNodes();
+
+    QDate startDate() const;
+    QDate endDate() const;
+
+public Q_SLOTS:
+    virtual void setProject(KPlato::Project *project);
+    virtual void setScheduleManager(KPlato::ScheduleManager *sm);
+    virtual void setReadWrite(bool rw);
+
 };
 
 } //namespace KPlato
