@@ -17,7 +17,8 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include "kplatomodels_export.h"
+// clazy:excludeall=qstring-arg
+#include "planmodels_export.h"
 #include "ReportGeneratorOdt.h"
 
 #include "kptproject.h"
@@ -60,6 +61,13 @@ const QLoggingCategory &PLANRG_LOG()
 }
 #define dbgRG qCDebug(PLANRG_LOG)<<Q_FUNC_INFO
 
+const QLoggingCategory &PLANRG_TMP_LOG()
+{
+    static const QLoggingCategory category("calligra.plan.reportodt.template");
+    return category;
+}
+#define dbgRGTmp qCDebug(PLANRG_TMP_LOG)<<Q_FUNC_INFO
+
 const QLoggingCategory &PLANRG_TABLE_LOG()
 {
     static const QLoggingCategory category("calligra.plan.reportodt.table");
@@ -104,8 +112,8 @@ ChartItemModel *findChartItemModel(QSortFilterProxyModel &model)
 
 bool startsWith(const QStringList &keys, const QString &key)
 {
-    for (const QString k : keys) {
-        if (key.startsWith(k)) {
+    for (const QString &k : keys) {
+        if (key.toLower().startsWith(k)) {
             return true;
         }
     }
@@ -159,20 +167,20 @@ bool addDataToFile(QByteArray &buffer, const QString &destName, KoStore &to)
 
 QAbstractItemModel *translationModel()
 {
-    QStandardItemModel *model = new QStandardItemModel();
-    QMap<QString, QString> names;
-    names["Project"] = i18n("Project");
-    names["Manager"] = i18n("Manager");
-    names["Schedule"] = i18n("Schedule");
-    names["BCWS"] = xi18nc("@title:column Budgeted Cost of Work Scheduled", "BCWS");
-    names["BCWP"] = xi18nc("@title:column Budgeted Cost of Work Performed", "BCWP");
-    names["ACWP"] = xi18nc("@title:column Actual Cost of Work Performed", "ACWP");
-    names["SPI"] = xi18nc("@title:column Schedule Performance Index", "SPI");
-    names["CPI"] = xi18nc("@title:column Cost Performance Index", "CPI");
+    QList<QPair<QString, QString> > names;
+    names << QPair<QString, QString>("Project", i18n("Project"))
+    << QPair<QString, QString>("Manager", i18n("Manager"))
+    << QPair<QString, QString>("Schedule", i18n("Schedule"))
+    << QPair<QString, QString>("BCWS", xi18nc("@title:column Budgeted Cost of Work Scheduled", "BCWS"))
+    << QPair<QString, QString>("BCWP", xi18nc("@title:column Budgeted Cost of Work Performed", "BCWP"))
+    << QPair<QString, QString>("ACWP", xi18nc("@title:column Actual Cost of Work Performed", "ACWP"))
+    << QPair<QString, QString>("SPI", xi18nc("@title:column Schedule Performance Index", "SPI"))
+    << QPair<QString, QString>("CPI", xi18nc("@title:column Cost Performance Index", "CPI"));
 
+    QStandardItemModel *model = new QStandardItemModel(0, names.count());
     for (int column = 0; column < names.count(); ++column) {
-        model->setHeaderData(column, Qt::Horizontal, names.values().at(column));
-        model->setHeaderData(column, Qt::Horizontal, names.keys().at(column), HeaderRole);
+        model->setHeaderData(column, Qt::Horizontal, names.at(column).first, HeaderRole);
+        model->setHeaderData(column, Qt::Horizontal, names.at(column).second);
     }
     return model;
 }
@@ -249,7 +257,7 @@ void initScheduleModel(QAbstractItemModel *model, Project *project, ScheduleMana
         for (QModelIndex i = idx; i.isValid(); i = i.sibling(i.row(), i.column() + 1)) {
             QModelIndex midx = model->index(0, i.column());
             model->setData(midx, i.data());
-            dbgRGVariable<<model->headerData(midx.column(), Qt::Horizontal, HeaderRole).toString()<<'='<<i.data().toString();
+            dbgRGVariable<<model->headerData(midx.column(), Qt::Horizontal, HeaderRole).toString()<<'='<<i.data(Qt::UserRole+1).toString();
         }
     } else dbgRGVariable<<"Could not find schedule"<<sm;
     dbgRGVariable<<model->rowCount()<<model->columnCount();
@@ -269,31 +277,28 @@ ReportGeneratorOdt::ReportGeneratorOdt()
     << new ChartItemModel()
     << new ScheduleItemModel();
 
-    m_datamodels["tasks"] = m_basemodels.at(0);
-    m_headerrole["tasks"] = Qt::EditRole;
-    m_datamodels["taskstatus"] = m_basemodels.at(1);
-    m_headerrole["taskstatus"] = Qt::EditRole;
-    m_datamodels["chart.project"] = m_basemodels.at(2);
-    m_headerrole["chart.project"] = Qt::EditRole;
-    m_datamodels["projects"] = projectModel();
-    m_headerrole["projects"] = HeaderRole;
-    m_datamodels["schedules"] = m_basemodels.at(3);
-    m_headerrole["schedules"] = Qt::EditRole;
+    addDataModel("tasks", m_basemodels.at(0), Qt::EditRole);
+    addDataModel("taskstatus", m_basemodels.at(1), Qt::EditRole);
+    addDataModel("chart.project", m_basemodels.at(2), Qt::EditRole);
+    addDataModel("projects", projectModel(), HeaderRole);
+    addDataModel("schedules", m_basemodels.at(3), Qt::EditRole);
+    addDataModel("project", projectModel(), HeaderRole);
+    addDataModel("schedule", scheduleModel(), HeaderRole);
+    addDataModel("tr", translationModel(), HeaderRole);
 
-    m_datamodels["project"] = projectModel();
-    m_headerrole["project"] = HeaderRole;
-
-    m_datamodels["schedule"] = scheduleModel();
-    m_headerrole["schedule"] = HeaderRole;
-
-    m_datamodels["tr"] = translationModel();
-    m_headerrole["tr"] = HeaderRole;
+//     for (QAbstractItemModel *m : m_datamodels) {
+//         const QString key = m_datamodels.key(m);
+//         qInfo()<<key<<"columns:"<<m->columnCount();
+//         for (int i = 0; i < m->columnCount(); ++i) {
+//             qInfo()<<'\t'<<i<<m->headerData(i, Qt::Horizontal, m_headerrole.value(key)).toString();
+//         }
+//     }
 }
 
 
 ReportGeneratorOdt::~ReportGeneratorOdt()
 {
-    for (QAbstractItemModel *m : m_datamodels) {
+    for (QAbstractItemModel *m : m_datamodels) { // clazy:exclude=range-loop
         if (!m_basemodels.contains(qobject_cast<ItemModelBase*>(m))) {
             delete m;
         }
@@ -302,6 +307,13 @@ ReportGeneratorOdt::~ReportGeneratorOdt()
     close();
 }
 
+void ReportGeneratorOdt::addDataModel(const QString &name, QAbstractItemModel *model, int role)
+{
+    model->setObjectName(name);
+    m_datamodels[name] = model;
+    m_headerrole[name] = role;
+}
+
 bool ReportGeneratorOdt::open()
 {
     m_lastError.clear();
@@ -317,13 +329,17 @@ bool ReportGeneratorOdt::open()
         m_lastError = i18n("Report generator is already open");
         return false;
     }
+    if (!QFile::exists(m_templateFile)) {
+        m_lastError = i18n("Report template file does not exist");
+        return false;
+    }
     m_templateStore = KoStore::createStore(m_templateFile, KoStore::Read);
     if (!m_templateStore) {
         dbgRG<<"Failed to open store:"<<m_templateFile;
         m_lastError = i18n("Failed to open template file: %1", m_templateFile);
         return false;
     }
-    for (ItemModelBase *m : m_basemodels) {
+    for (ItemModelBase *m : m_basemodels) { // clazy:exclude=range-loop
         m->setProject(m_project);
         m->setScheduleManager(m_manager);
         if (qobject_cast<ChartItemModel*>(m)) {
@@ -334,6 +350,7 @@ bool ReportGeneratorOdt::open()
     initProjectModel(m_datamodels["projects"], m_project, m_manager);
     initProjectModel(m_datamodels["project"], m_project, m_manager);
     initScheduleModel(m_datamodels["schedule"], m_project, m_manager);
+    static_cast<ScheduleItemModel*>(m_datamodels["schedules"])->setProject(m_project);
     return true;
 }
 
@@ -371,10 +388,12 @@ bool ReportGeneratorOdt::createReportOdt()
     }
     dbgRG << endl << "---- treat main content.xml ----" << endl;
     QBuffer buffer;
-    KoXmlWriter *writer = KoOdfWriteStore::createOasisXmlWriter(&buffer, "office:document-content");
-    // HACK: add loext namespace in case template is created using libreoffice
-    writer->addAttribute("xmlns:loext", "urn:org:documentfoundation:names:experimental:office:xmlns:loext:1.0");
+    KoXmlWriter *writer = createOasisXmlWriter(reader, &buffer, "content.xml", "office:document-content");
 
+    if (!writer) {
+        dbgRG<<"Failed to create content.xml writer";
+        return false;
+    }
     KoXmlDocument kodoc = reader.contentDoc();
     KoXmlElement parent = kodoc.documentElement();
     writeChildElements(*writer, parent);
@@ -394,7 +413,11 @@ bool ReportGeneratorOdt::createReportOdt()
     if (m_manifestfiles.contains("styles.xml")) {
         dbgRG << endl << "---- treat styles.xml (for master-page headers/footers) ----" << endl;
         QBuffer buffer2;
-        KoXmlWriter *styles = KoOdfWriteStore::createOasisXmlWriter(&buffer2, "office:document-styles");
+        KoXmlWriter *styles = createOasisXmlWriter(reader, &buffer2, "styles.xml", "office:document-styles");
+        if (!styles) {
+            dbgRG<<"Failed to create styles.xml writer";
+            return false;
+        }
         KoXmlDocument stylesDoc;
         if (!reader.loadAndParse("styles.xml", stylesDoc, m_lastError)) {
             debugPlan<<"Failed to read styles.xml"<<m_lastError;
@@ -417,8 +440,8 @@ bool ReportGeneratorOdt::createReportOdt()
     dbgRG << endl << "---- treat the embedded files ----" << endl;
     treatEmbededObjects(reader, *outStore);
     dbgRG << endl << "---- copy rest of files ----" << endl;
-    for (const QString &f : m_manifestfiles) {
-        copyFile(*reader.store(), *outStore, f);
+    for (int i = 0; i < m_manifestfiles.count(); ++i) {
+        copyFile(*reader.store(), *outStore, m_manifestfiles.at(i));
     }
     if (!outStore->finalize()) {
         dbgRG<<"Failed to write store:"<<outStore->urlOfStore();
@@ -447,6 +470,7 @@ bool ReportGeneratorOdt::handleTextP(KoXmlWriter &writer, const KoXmlElement &te
             dbgRG<<"Check:"<<field<<m_userfields;
             if (m_userfields.contains(field) && startsWith(m_keys, field)) {
                 m_sortedfields << field;
+                m_userfields[field]->finish();
                 dbgRG<<"Found:"<<tag<<field;
                 return false;
             } else {
@@ -509,7 +533,7 @@ void ReportGeneratorOdt::treatTable(KoXmlWriter &writer, const KoXmlElement &tab
         m_sortedfields.takeFirst();
         m_activefields << name;
         UserField *field = m_userfields[name];
-        field->seqNr = -1;
+        field->seqNr = USERFIELD_NONE;
         dbgRGTable<<field;
         writer.startElement("table:table");
         writeElementAttributes(writer, tableElement);
@@ -535,7 +559,7 @@ bool ReportGeneratorOdt::treatTableHeaderRows(KoXmlWriter &writer, const KoXmlEl
     }
     dbgRGTable;
     UserField *field = m_userfields[m_activefields.last()];
-    field->seqNr = 0; // we are in header row
+    field->seqNr = USERFIELD_HEADER; // we are in header row
     return false;
 }
 
@@ -546,17 +570,17 @@ bool ReportGeneratorOdt::treatTableRow(KoXmlWriter &writer, const KoXmlElement &
     }
     UserField *field = m_userfields[m_activefields.last()];
     dbgRGTable<<field->seqNr;
-    if (field->seqNr == -1) {
+    if (field->seqNr == USERFIELD_NONE) {
         // there is no header row, so start with data rows directly
-        field->seqNr = 1;
+        field->seqNr = USERFIELD_DATA;
     }
-    if (field->seqNr == 0) {
+    if (field->seqNr == USERFIELD_HEADER) {
         // header row
         writer.startElement("table:table-row");
         writeElementAttributes(writer, rowElement);
         writeChildElements(writer, rowElement);
         writer.endElement();
-        field->seqNr = 1; // next is first row
+        field->seqNr = USERFIELD_DATA; // next is first row
     } else {
         dbgRGTable<<" add rows:"<<field->rowCount();
         for (field->begin(); field->next();) {
@@ -565,6 +589,7 @@ bool ReportGeneratorOdt::treatTableRow(KoXmlWriter &writer, const KoXmlElement &
             writeChildElements(writer, rowElement);
             writer.endElement();
         }
+        field->finish();
     }
     return true;
 }
@@ -577,9 +602,10 @@ ReportGeneratorOdt::UserField *ReportGeneratorOdt::findUserField(const KoXmlElem
     field = m_userfields.value(name); // if Variable or Translation
     if (!field) {
         QStringList lst = name.split('.');
-        for (const QString k : m_userfields.keys()) {
-            if (lst.first().startsWith(k)) {
-                field = m_userfields[k];
+        QMap<QString, UserField*>::const_iterator it;
+        for (it = m_userfields.constBegin(); it != m_userfields.constEnd(); ++it) {
+            if (lst.first().startsWith(it.key())) {
+                field = it.value();
                 break;
             }
         }
@@ -640,7 +666,7 @@ void ReportGeneratorOdt::handleUserFieldDecls(KoXmlWriter &writer, const KoXmlEl
         if (tag != "text:user-field-decl") {
             continue;
         }
-        QString name = e.attributeNS(KoXmlNS::text, "name").toLower();
+        QString name = e.attributeNS(KoXmlNS::text, "name");
         if (name.isEmpty()) {
             dbgRG<<"  User field name is empty";
             continue;
@@ -657,7 +683,7 @@ void ReportGeneratorOdt::handleUserFieldDecls(KoXmlWriter &writer, const KoXmlEl
             m_userfields[field->name] = field;
 
             field->dataName = value;
-            field->seqNr = -3;
+            field->seqNr = USERFIELD_TRANSLATION;
             field->columns << value;
             field->setModel(dataModel("tr"), m_headerrole["tr"]);
             dbgRGTr<<"    added translation"<<field->name<<field->dataName;
@@ -670,7 +696,7 @@ void ReportGeneratorOdt::handleUserFieldDecls(KoXmlWriter &writer, const KoXmlEl
             m_userfields[field->name] = field;
 
             field->dataName = tags.first();
-            field->seqNr = -2;
+            field->seqNr = USERFIELD_VARIABLE;
             QStringList vl = value.split(';');
             if (!vl.isEmpty()) {
                 field->columns << vl.takeFirst();
@@ -679,13 +705,13 @@ void ReportGeneratorOdt::handleUserFieldDecls(KoXmlWriter &writer, const KoXmlEl
             field->setModel(dataModel(field->dataName), m_headerrole[field->dataName]);
             dbgRGVariable<<"    added variable"<<field->name<<field->columns<<field->properties;
         } else {
-            for (const QString k : m_keys) {
+            for (const QString &k : m_keys) { // clazy:exclude=range-loop
                 const QString vname = tags.first();
                 if (!vname.startsWith(k)) {
                     continue;
                 }
                 if (tags.count() == 1) {
-                    // this is the main definition (eg: name: "table1", value: "tasks ...")
+                    // this is the main definition (eg: name: "table1", value: "project; values=bcws effort, bcwp effort, acwp effort;")
                     if (!m_userfields.contains(vname)) {
                         m_userfields[vname] = new UserField();
                     }
@@ -705,10 +731,12 @@ void ReportGeneratorOdt::handleUserFieldDecls(KoXmlWriter &writer, const KoXmlEl
                     // this is the fields column definitions (eg: name: "table1.type" value: "<not used>")
                     if (!m_userfields.contains(vname)) {
                         m_userfields[vname] = new UserField();
+                        UserField *field = m_userfields[vname];
+                        field->name = vname;
                     }
                     UserField *field = m_userfields[vname];
-                    field->name = vname;
                     field->columns << value.trimmed().toLower();
+                    Q_ASSERT(field->name == vname);
                     dbgRG<<"  "<<"added column:"<<field->name<<field->columns;
                 }
             }
@@ -723,7 +751,7 @@ void ReportGeneratorOdt::handleUserFieldDecls(KoXmlWriter &writer, const KoXmlEl
 
 void ReportGeneratorOdt::writeElementAttributes(KoXmlWriter &writer, const KoXmlElement &element, const QStringList &exclude)
 {
-    for (const QPair<QString, QString> &a : element.attributeFullNames()) {
+    for (const QPair<QString, QString> &a : element.attributeFullNames()) { // clazy:exclude=range-loop
         QString prefix = KoXmlNS::nsURI2NS(a.first);
         if (prefix.isEmpty()) {
             dbgRG<<"  Skipping unknown namespace:"<<a.first<<a.second;
@@ -833,7 +861,7 @@ KoStore *ReportGeneratorOdt::copyStore(KoOdfReadStore &reader, const QString &ou
     if (!url.isLocalFile()) {
         // FIXME: KoStore only handles local files
         dbgRG<<"KoStore only handles local files";
-        m_lastError = i18n("Report generator can only handle local files");
+        m_lastError = i18n("Report generator can only generate local files");
         return 0;
     }
     KoStore *out = KoStore::createStore(url.path(), KoStore::Write);
@@ -874,6 +902,57 @@ KoStore *ReportGeneratorOdt::copyStore(KoOdfReadStore &reader, const QString &ou
     return out;
 }
 
+KoXmlWriter *ReportGeneratorOdt::createOasisXmlWriter(KoOdfReadStore &reader, QBuffer *buffer, const QString fileName, const char *rootElementName)
+{
+    if (!reader.store()) {
+        m_lastError = i18n("No store backend");
+        dbgRG<<"No store";
+        return 0;
+    }
+    dbgRGTmp<<fileName<<rootElementName<<"has file:"<<reader.store()->hasFile(fileName);
+    if (reader.store()->isOpen()) {
+        reader.store()->close();
+    }
+    if (!reader.store()->open(fileName)) {
+        dbgRG << "Entry " << fileName << " not found!";
+        m_lastError = xi18nc("@info", "Failed to open file <filename>%1</filename> from store.", fileName);
+        return 0;
+    }
+    if (!reader.store()->device()->isOpen()) {
+        reader.store()->device()->open(QIODevice::ReadOnly);
+    }
+    KoXmlWriter *writer = 0;
+    QXmlStreamReader xml(reader.store()->device());
+    xml.setNamespaceProcessing(true);
+    while (!xml.atEnd()) {
+        xml.readNext();
+        if (xml.tokenType() == QXmlStreamReader::StartElement && !xml.namespaceDeclarations().isEmpty()) {
+            writer = new KoXmlWriter(buffer);
+            writer->startDocument(rootElementName);
+            writer->startElement(rootElementName);
+            writer->addAttribute("xmlns:calligra", KoXmlNS::calligra);
+
+            // Note: windows needs this type of iteration
+            QXmlStreamNamespaceDeclarations dcl = xml.namespaceDeclarations();
+            for (int ns = 0; ns < dcl.count(); ++ns) {
+                dbgRGTmp<<"add namespace:"<<("xmlns:" + dcl[ns].prefix())<<dcl[ns].namespaceUri();
+                writer->addAttribute(("xmlns:" + dcl[ns].prefix()).toLatin1(), dcl[ns].namespaceUri().toUtf8());
+            }
+            QXmlStreamAttributes attr = xml.attributes();
+            for (int a = 0; a < attr.count(); ++a) {
+                dbgRGTmp<<"add attribute:"<<attr[a].qualifiedName().toString()<<attr[a].value().toString();
+                writer->addAttribute(attr[a].qualifiedName().toLatin1(), attr[a].value().toUtf8());
+            }
+        }
+    }
+    reader.store()->close();
+    if (!writer) {
+        dbgRG<<"Failed to find a start element with namespace declarations in"<<fileName;
+        m_lastError = xi18nc("@info", "Missing namespace declarations:<nl/><filename>%1</filename>", fileName);
+    }
+    return writer;
+}
+
 void ReportGeneratorOdt::treatEmbededObjects(KoOdfReadStore &reader, KoStore &outStore)
 {
     dbgRGChart;
@@ -912,17 +991,17 @@ void ReportGeneratorOdt::treatChart(KoOdfReadStore &reader, KoStore &outStore, c
         }
         if (field->properties.isEmpty()) {
             // default: take all
-            for (const QString &c : field->headerNames) {
+            for (const QString &c : field->headerNames) { // clazy:exclude=range-loop
                 field->columns << c;
             }
         } else {
             QStringList values;
-            for (const QString &p : field->properties) {
+            for (const QString &p : field->properties) { // clazy:exclude=range-loop
                 if (p.startsWith("values")) {
                     QStringList vl = p.split("=");
                     Q_ASSERT(vl.count() > 1);
                     Q_ASSERT(vl.at(0) == "values");
-                    for (const QString &v : vl.at(1).split(',')) {
+                    for (const QString &v : vl.at(1).split(',')) {  // clazy:exclude=range-loop
                         values << v.toLower().trimmed();
                     }
                 }
@@ -933,7 +1012,7 @@ void ReportGeneratorOdt::treatChart(KoOdfReadStore &reader, KoStore &outStore, c
 
     }
     QBuffer buffer;
-    KoXmlWriter *writer = KoOdfWriteStore::createOasisXmlWriter(&buffer, "office:document-content");
+    KoXmlWriter *writer = createOasisXmlWriter(reader, &buffer, file, "office:document-content");
 
     writeChartElements(*writer, doc.documentElement());
 
@@ -1062,7 +1141,7 @@ void ReportGeneratorOdt::writeChartElements(KoXmlWriter &writer, const KoXmlElem
             writer.endElement();
             // write legends
             UserField *field = m_userfields[m_activefields.last()];
-            for (const QString &name : field->columns) {
+            for (const QString &name : field->columns) { // clazy:exclude=range-loop
                 QString value = field->headerData(name);
                 writer.startElement("table:table-cell");
                 writer.addAttribute("office:value-type", "string");
@@ -1093,7 +1172,7 @@ void ReportGeneratorOdt::writeChartElements(KoXmlWriter &writer, const KoXmlElem
                     writer.endElement();
                     writer.endElement();
                     // then the data
-                    for (const QString &name : field->columns) {
+                    for (const QString &name : field->columns) { // clazy:exclude=range-loop
                         QVariant value = field->model.index(r, field->column(name)).data();
                         writer.startElement("table:table-cell");
                         writer.addAttribute("office:value-type", "float");
@@ -1107,6 +1186,22 @@ void ReportGeneratorOdt::writeChartElements(KoXmlWriter &writer, const KoXmlElem
                 }
             }
             writer.endElement();
+        } else if (tag == "chart:legend") {
+            writer.startElement(tag.constData());
+            if (!e.hasAttributeNS(KoXmlNS::chart, "legend-align") && e.hasAttributeNS(KoXmlNS::chart, "legend-position")) {
+                // lowriter does not specify this attribute
+                // If legend-position is start, end, top or bottom
+                // we need to have legend-align == center so that words
+                // repositions the legend correctly
+                QStringList lst = QStringList() << "start" << "end" << "top" << "bottom";
+                if (lst.contains(e.attributeNS(KoXmlNS::chart, "legend-position"))) {
+                    writer.addAttribute("chart:legend-align", "center");
+                    dbgRGChart<<"adding legend-align";
+                }
+            }
+            writeElementAttributes(writer, e);
+            writeChartElements(writer, e);
+            writer.endElement();
         } else {
             writer.startElement(tag.constData());
             writeElementAttributes(writer, e);
@@ -1171,17 +1266,25 @@ bool ReportGeneratorOdt::UserField::next()
         currentIndex = model.index(0, column(columns.value(0)), currentIndex);
     } else {
         do {
-            QModelIndex idx = model.index(currentIndex.row()+1, column(columns.value(0)), currentIndex.parent());
+            QModelIndex idx = currentIndex.sibling(currentIndex.row()+1, column(columns.value(0)));
             if (idx.isValid()) {
                 currentIndex = idx;
                 break;
             }
-            currentIndex = currentIndex.parent();
+            currentIndex = model.parent(currentIndex);
         } while (currentIndex.isValid());
     }
     return currentIndex.isValid();
 }
 
+void ReportGeneratorOdt::UserField::finish()
+{
+    currentIndex = QModelIndex();
+    if (seqNr > USERFIELD_NONE) {
+        seqNr = USERFIELD_NONE;
+    }
+}
+
 QString ReportGeneratorOdt::UserField::data(const QString &column) const
 {
     QModelIndex idx;
@@ -1214,10 +1317,10 @@ int ReportGeneratorOdt::UserField::variant() const
 {
     int t = Rows;
     switch (seqNr) {
-        case -3: t = Translation; break;
-        case -2: t = Variable; break;
-        case -1: t = None; break;
-        case 0: t = Header; break;
+        case USERFIELD_TRANSLATION: t = Translation; break;
+        case USERFIELD_VARIABLE: t = Variable; break;
+        case USERFIELD_NONE: t = None; break;
+        case USERFIELD_HEADER: t = Header; break;
         default: break;
     }
     return t;
@@ -1236,20 +1339,20 @@ QDebug operator<<(QDebug dbg, ReportGeneratorOdt::UserField &f)
     dbg.nospace() << "UserField[";
     switch (f.variant()) {
         case ReportGeneratorOdt::UserField::Header: dbg << "H: " + f.name + '.' + f.dataName; break;
-        case ReportGeneratorOdt::UserField::Rows: dbg << "R: " + f.name + '.' + f.dataName; break;
+        case ReportGeneratorOdt::UserField::Rows: dbg << "R: " + f.name + '.' + f.dataName << "seqNr: " << f.seqNr; break;
         case ReportGeneratorOdt::UserField::Variable: dbg << "V: " + f.name; break;
         case ReportGeneratorOdt::UserField::Translation: dbg << "T: " + f.name; break;
         default: dbg << "U: " + f.name; break;
     }
-    if (!f.columns.isEmpty()) {
-        dbg << endl <<"Columns: " << f.columns;
-    }
-    if (!f.headerNames.isEmpty()) {
-        dbg << endl << "Headers: " << f.headerNames;
-    }
-    if (!f.columns.isEmpty() || !f.headerNames.isEmpty()) {
-        dbg << endl;
-    }
+//     if (!f.columns.isEmpty()) {
+//         dbg << endl <<"Columns: " << f.columns;
+//     }
+//     if (!f.headerNames.isEmpty()) {
+//         dbg << endl << "Headers: " << f.headerNames;
+//     }
+//     if (!f.columns.isEmpty() || !f.headerNames.isEmpty()) {
+//         dbg << endl;
+//     }
     dbg << ']';
     return dbg.space();
 }
