@@ -66,6 +66,9 @@ namespace KPlato
 // sort indexes the way they are displayed
 void sort(const QTreeView *view, QModelIndexList &list)
 {
+    if (list.count() <= 1) {
+        return;
+    }
     QModelIndexList i; i << list.takeFirst();
     for (QModelIndex idx = view->indexAbove(i.first()); idx.isValid() && !list.isEmpty(); idx = view->indexAbove(idx)) {
         if (list.contains(idx)) {
@@ -268,8 +271,8 @@ PrintingOptions PrintingHeaderFooter::options() const
     return opt;
 }
 
-PrintingDialog::PrintingDialog(ViewBase *view)
-    : KoPrintingDialog(view),
+PrintingDialog::PrintingDialog(ViewBase *view, QPrinter::PrinterMode mode)
+    : KoPrintingDialog(view, mode),
     m_view(view),
     m_widget(0)
 {
@@ -571,6 +574,15 @@ void PrintingDialog::paint(QPainter &p, const PrintingOptions::Data &options, co
     p.restore();
 }
 
+//--------------
+void ViewActionLists::addContextAction(QAction *action, int pos) {
+    if (pos > m_contextActionList.count()) {
+        m_contextActionList.append(action);
+    } else {
+        m_contextActionList.insert(pos, action);
+    }
+}
+
 //--------------
 ViewBase::ViewBase(KoPart *part, KoDocument *doc, QWidget *parent)
     : KoView(part, doc, parent),
@@ -2745,11 +2757,11 @@ void DoubleTreeViewBase::setContextMenuIndex(const QModelIndex &idx)
 QMimeData *DoubleTreeViewBase::mimeData() const
 {
     QModelIndexList rows = selectionModel()->selectedRows();
-    sort(m_leftview, rows);
     if (rows.isEmpty()) {
         debugPlan<<"No rows selected";
         return 0;
     }
+    sort(m_leftview, rows);
     QList<int> columns;;
     columns = m_leftview->visualColumns() + m_rightview->visualColumns();
     QModelIndexList indexes;
