@@ -151,7 +151,7 @@ class PLANUI_EXPORT PrintingDialog : public KoPrintingDialog
 {
     Q_OBJECT
 public:
-    explicit PrintingDialog(ViewBase *view);
+    explicit PrintingDialog(ViewBase *view, QPrinter::PrinterMode mode = QPrinter::ScreenResolution);
     ~PrintingDialog() override;
 
     QList<QWidget*> createOptionWidgets() const override;
@@ -194,7 +194,7 @@ public:
     virtual ~ViewActionLists() {}
 
     QList<QAction*> contextActionList() const { return m_contextActionList; }
-    void addContextAction(QAction *action, int pos = INT_MAX) { m_contextActionList.insert(pos, action); }
+    void addContextAction(QAction *action, int pos = INT_MAX);
 
 protected:
     /// List of actions that will be shown in the views header context menu
