@@ -17,6 +17,7 @@
   Boston, MA 02110-1301, USA.
 */
 
+// clazy:excludeall=qstring-arg
 #include "ReportsGeneratorView.h"
 
 #include "reportgenerator/ReportGenerator.h"
@@ -25,12 +26,15 @@
 
 #include <KoIcon.h>
 #include <KoXmlReader.h>
+#include <KoDocument.h>
 
 #include <KActionCollection>
 #include <KUrlRequester>
 #include <KFile>
+#include <KRun>
 
 #include <QAction>
+#include <QHeaderView>
 #include <QTreeView>
 #include <QStandardItemModel>
 #include <QModelIndex>
@@ -43,7 +47,6 @@
 #include <QUrl>
 #include <QMap>
 #include <QMessageBox>
-#include <QDebug>
 
 namespace KPlato
 {
@@ -55,9 +58,9 @@ class TemplateFileDelegate : public QStyledItemDelegate
 public:
     TemplateFileDelegate(QObject *parent);
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    void setEditorData(QWidget *editor, const QModelIndex &index) const;
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 
     QMap<QString, QUrl> files;
 };
@@ -71,14 +74,13 @@ QWidget *TemplateFileDelegate::createEditor(QWidget *parent, const QStyleOptionV
 {
     Q_UNUSED(option)
     Q_UNUSED(index);
-    qDebug()<<Q_FUNC_INFO;
     return new QComboBox(parent);
 }
 
 void TemplateFileDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     QComboBox *cb = qobject_cast<QComboBox*>(editor);
-    qDebug()<<Q_FUNC_INFO<<cb;
+    debugPlan<<cb;
     if (!cb) {
         return;
     }
@@ -91,19 +93,20 @@ void TemplateFileDelegate::setEditorData(QWidget *editor, const QModelIndex &ind
 void TemplateFileDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     QComboBox *cb = qobject_cast<QComboBox*>(editor);
-    qDebug()<<Q_FUNC_INFO<<cb;
+    debugPlan<<cb;
     if (cb) {
         QString cfile = index.data().toString();
         QString nfile = cb->currentText();
-        qDebug()<<"template file:"<<nfile<<files;
+        debugPlan<<"template file:"<<nfile<<files;
         if (cfile != nfile) {
             model->setData(index, nfile);
             if (files.contains(nfile)) {
                 nfile = files[nfile].url();
             }
             model->setData(index, nfile, FULLPATHROLE);
+            model->setData(index, nfile, Qt::ToolTipRole);
         }
-    } else qDebug()<<"  No combo box editor!!";
+    } else debugPlan<<"  No combo box editor!!";
 }
 
 class FileItemDelegate : public QStyledItemDelegate
@@ -111,9 +114,9 @@ class FileItemDelegate : public QStyledItemDelegate
 public:
     FileItemDelegate(QObject *parent);
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    void setEditorData(QWidget *editor, const QModelIndex &index) const;
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 
     QMap<QString, QUrl> files;
 };
@@ -154,9 +157,9 @@ class FileNameExtensionDelegate : public QStyledItemDelegate
 public:
     FileNameExtensionDelegate(QObject *parent);
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    void setEditorData(QWidget *editor, const QModelIndex &index) const;
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 
 };
 
@@ -209,6 +212,12 @@ ReportsGeneratorView::ReportsGeneratorView(KoPart *part, KoDocument *doc, QWidge
     : ViewBase(part, doc, parent)
 {
     debugPlan<<"----------------- Create ReportsGeneratorView ----------------------";
+    if (doc && doc->isReadWrite()) {
+        setXMLFile("ReportsGeneratorViewUi.rc");
+    } else {
+        setXMLFile("ReportsGeneratorViewUi_readonly.rc");
+    }
+
     QVBoxLayout * l = new QVBoxLayout(this);
     l->setMargin(0);
     m_view = new QTreeView(this);
@@ -223,19 +232,21 @@ ReportsGeneratorView::ReportsGeneratorView(KoPart *part, KoDocument *doc, QWidge
     m_view->setRootIsDecorated(false);
     m_view->setAlternatingRowColors(true);
 
-    connect(m_view, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(slotContextMenuRequested(const QPoint&)));
+    updateReadWrite(doc && doc->isReadWrite());
+
+    connect(m_view, &QWidget::customContextMenuRequested, this, &ReportsGeneratorView::slotContextMenuRequested);
     l->addWidget(m_view);
 
     TemplateFileDelegate *del = new TemplateFileDelegate(m_view);
     QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "reports", QStandardPaths::LocateDirectory);
-    qDebug()<<"standardpath:"<<path;
+    debugPlan<<"standardpath:"<<path;
     if (!path.isEmpty()) {
         QDir dir(path);
-        qDebug()<<dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot);
-        for (const QString &file : dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot)) {
+        debugPlan<<dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot);
+        foreach(const QString &file, dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot)) {
             QUrl url;
             url.setUrl(path + '/' + file);
-            qDebug()<<"templates:"<<url<<path<<file;
+            debugPlan<<"templates:"<<url<<path<<file;
             del->files.insert(url.fileName(), url);
         }
     }
@@ -247,7 +258,7 @@ ReportsGeneratorView::ReportsGeneratorView(KoPart *part, KoDocument *doc, QWidge
     m_view->header()->setSectionResizeMode(3, QHeaderView::Fixed);
     m_view->header()->resizeSection(3, 12);
 
-    connect(m_view->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)), this, SLOT(slotSelectionChanged()));
+    connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ReportsGeneratorView::slotSelectionChanged);
     setupGui();
 
     Help::add(this,
@@ -258,7 +269,23 @@ ReportsGeneratorView::ReportsGeneratorView(KoPart *part, KoDocument *doc, QWidge
                           "</para><para>"
                           "You can create a report template using any Open Document text editor."
                           "<nl/><link url='%1'>More...</link>"
-                          "</para>", Help::page("Manual/Reports_Generator_View")));
+                          "</para>", Help::page("Reports_Generator_View")));
+}
+
+void ReportsGeneratorView::updateReadWrite(bool rw)
+{
+    QStandardItemModel *m = static_cast<QStandardItemModel*>(m_view->model());
+    for (int r = 0; r < m->rowCount(); ++r) {
+        for (int c = 0; c < m->columnCount(); ++c) {
+            QStandardItem *item = m->itemFromIndex(m->index(r, c));
+            if (rw) {
+                item->setFlags(item->flags() | Qt::ItemIsEditable);
+            } else {
+                item->setFlags(item->flags() & ~Qt::ItemIsEditable);
+            }
+        }
+    }
+    ViewBase::updateReadWrite(rw);
 }
 
 void ReportsGeneratorView::setGuiActive(bool activate)
@@ -308,33 +335,24 @@ void ReportsGeneratorView::updateActionsEnabled(bool on)
 
 void ReportsGeneratorView::setupGui()
 {
-    // Umpff, adding a specific list name for this view in calligraplan.rc does not work!
-    // But reusing an already existing name works, so...
-    // Not important atm, the whole setup should be refactored anyway.
-    //QString name = "reportsgeneratorview_list";
-    QString name = "workpackage_list";
-
     KActionCollection *coll = actionCollection();
 
     actionAddReport = new QAction(koIcon("list-add"), i18n("Add Report"), this);
     coll->addAction("add_report", actionAddReport);
     coll->setDefaultShortcut(actionAddReport, Qt::CTRL + Qt::Key_I);
-    connect(actionAddReport, SIGNAL(triggered(bool)), SLOT(slotAddReport()));
-    addAction(name, actionAddReport);
+    connect(actionAddReport, &QAction::triggered, this, &ReportsGeneratorView::slotAddReport);
     addContextAction(actionAddReport);
 
     actionRemoveReport = new QAction(koIcon("list-remove"), i18n("Remove Report"), this);
     coll->addAction("remove_report", actionRemoveReport);
     coll->setDefaultShortcut(actionRemoveReport, Qt::CTRL + Qt::Key_D);
-    connect(actionRemoveReport, SIGNAL(triggered(bool)), SLOT(slotRemoveReport()));
-    addAction(name, actionRemoveReport);
+    connect(actionRemoveReport, &QAction::triggered, this, &ReportsGeneratorView::slotRemoveReport);
     addContextAction(actionRemoveReport);
 
     actionGenerateReport = new QAction(koIcon("document-export"), i18n("Generate Report"), this);
     coll->addAction("generate_report", actionGenerateReport);
     coll->setDefaultShortcut(actionGenerateReport, Qt::CTRL + Qt::Key_G);
-    connect(actionGenerateReport, SIGNAL(triggered(bool)), SLOT(slotGenerateReport()));
-    addAction(name, actionGenerateReport);
+    connect(actionGenerateReport, &QAction::triggered, this, &ReportsGeneratorView::slotGenerateReport);
     addContextAction(actionGenerateReport);
 
 //     createOptionAction();
@@ -394,7 +412,7 @@ void ReportsGeneratorView::slotGenerateReport()
 {
     debugPlan;
     QAbstractItemModel *model = m_view->model();
-    for (const QModelIndex &idx : selectedRows()) {
+    foreach(const QModelIndex &idx, selectedRows()) {
         QString name = model->index(idx.row(), 0).data().toString();
         QString tmp = model->index(idx.row(), 1).data(FULLPATHROLE).toString();
         QString file = model->index(idx.row(), 2).data().toString();
@@ -451,7 +469,9 @@ bool ReportsGeneratorView::generateReport(const QString &templateFile, const QSt
         QMessageBox::warning(this, i18n("Failed to create report"), rg.lastError());
         return false;
     }
-    QMessageBox::information(this, i18n("Report Generation"), i18n("Report file generated: %1", file));
+    if (QMessageBox::question(this, xi18nc("@title:window", "Report Generation"), xi18nc("@info", "Report file generated:<nl/><filename>%1</filename>", file), QMessageBox::Open|QMessageBox::Close, QMessageBox::Close) == QMessageBox::Open) {
+        return KRun::runUrl(QUrl(file), "application/vnd.oasis.opendocument.text", window(), (KRun::RunFlags)0);
+    }
     return true;
 }
 
@@ -490,6 +510,7 @@ bool ReportsGeneratorView::loadContext(const KoXmlElement &context)
             model->setData(idx, name);
             idx = model->index(row, 1);
             model->setData(idx, tmp, FULLPATHROLE);
+            model->setData(idx, tmp, Qt::ToolTipRole);
             model->setData(idx, QUrl(tmp).fileName());
             idx = model->index(row, 2);
             model->setData(idx, file);
@@ -503,13 +524,14 @@ bool ReportsGeneratorView::loadContext(const KoXmlElement &context)
     for (int c = 0; c < m_view->header()->count(); ++c) {
         m_view->resizeColumnToContents(c);
     }
+    updateReadWrite(isReadWrite());
     return true;
 }
 
 void ReportsGeneratorView::saveContext(QDomElement &context) const
 {
     debugPlan;
-    context.setAttribute( "stretch-last-column", QString::number(m_view->header()->stretchLastSection()) );
+    context.setAttribute("stretch-last-column", QString::number(m_view->header()->stretchLastSection()));
     QDomElement e = context.ownerDocument().createElement("sections");
     context.appendChild(e);
     QHeaderView *h = m_view->header();
