@@ -97,22 +97,20 @@ class KoDialogPrivate;
  * <b>Example:</b>\n
  *
  * \code
- *   KoDialog *dialog = new KoDialog( this );
- *   dialog->setCaption( "My title" );
- *   dialog->setButtons( KoDialog::Ok | KoDialog::Cancel | KoDialog::Apply );
+ *   KoDialog *dialog = new KoDialog(this);
+ *   dialog->setCaption("My title");
+ *   dialog->setButtons(KoDialog::Ok | KoDialog::Cancel | KoDialog::Apply);
  *
- *   FooWidget *widget = new FooWidget( dialog );
- *   dialog->setMainWidget( widget );
- *   connect( dialog, SIGNAL(applyClicked()), widget, SLOT(save()) );
- *   connect( dialog, SIGNAL(okClicked()), widget, SLOT(save()) );
- *   connect( widget, SIGNAL(changed(bool)), dialog, SLOT(enableButtonApply(bool)) );
+ *   FooWidget *widget = new FooWidget(dialog);
+ *   dialog->setMainWidget(widget);
+ *   connect(dialog, SIGNAL(applyClicked()), widget, SLOT(save()));
+ *   connect(dialog, SIGNAL(okClicked()), widget, SLOT(save()));
+ *   connect(widget, SIGNAL(changed(bool)), dialog, SLOT(enableButtonApply(bool)));
  *
- *   dialog->enableButtonApply( false );
+ *   dialog->enableButtonApply(false);
  *   dialog->show();
  * \endcode
  *
- * \image html kdialog.png "KDE Dialog example"
- *
  * This class can be used in many ways. Note that most KDE ui widgets
  * and many of KDE core applications use the KoDialog so for more
  * inspiration you should study the code for these.
@@ -128,7 +126,6 @@ class KoDialogPrivate;
 class KOWIDGETS_EXPORT KoDialog : public QDialog //krazy:exclude=qclasses
 {
     Q_OBJECT
-    Q_ENUMS(ButtonCode)
     Q_DECLARE_PRIVATE(KoDialog)
 
 public:
@@ -151,6 +148,7 @@ public:
         User3   = 0x00004000, ///< Show User defined button 3.
         NoDefault = 0x00008000 ///< Used when specifying a default button; indicates that no button should be marked by default.
     };
+    Q_ENUM(ButtonCode)
     // TODO KDE5: remove NoDefault and use the value None instead
     Q_DECLARE_FLAGS(ButtonCodes, ButtonCode)
 
@@ -172,7 +170,7 @@ public:
     /**
      * Destroys the dialog.
      */
-    ~KoDialog();
+    ~KoDialog() override;
 
     /**
      * Creates (or recreates) the button box and all the buttons in it.
@@ -396,15 +394,16 @@ public:
     static int groupSpacingHint();
 
     /**
-     * @enum StandardCaptionFlag
+     * @enum CaptionFlag
      * Used to specify how to construct a window caption
      *
-     * @value AppName Indicates that the method shall include
+     * @var NoCaptionFlags Indicates that the method has no caption flags.
+     * @var AppNameCaption Indicates that the method shall include
      * the application name when making the caption string.
-     * @value Modified Causes a 'modified' sign will be included in the
+     * @var ModifiedCaption Causes a 'modified' sign will be included in the
      * returned string. This is useful when indicating that a file is
      * modified, i.e., it contains data that has not been saved.
-     * @value HIGCompliant The base minimum flags required to align a
+     * @var HIGCompliantCaption The base minimum flags required to align a
      * caption with the KDE Human Interface Guidelines
      */
     enum CaptionFlag {
@@ -427,7 +426,7 @@ public:
      * be applied to.
      *
      * If using a KoDialog or KMainWindow subclass, call setCaption instead and
-     * an appropraite standard caption will be created for you
+     * an appropriate standard caption will be created for you
      *
      * @param userCaption The caption string you want to display in the
      * window caption area. Do not include the application name!
@@ -511,6 +510,11 @@ public:
      */
     QSize minimumSizeHint() const Q_DECL_OVERRIDE;
 
+    /**
+     * Returns the status of the Details button.
+     */
+    bool isDetailsWidgetVisible() const;
+
 public Q_SLOTS:
     /**
      * Make a KDE compliant caption.
@@ -550,7 +554,7 @@ public Q_SLOTS:
      * @param id Button identifier.
      * @param state @p true enables the button(s).
      */
-    void enableButton(ButtonCode id, bool state);
+    void enableButton(KoDialog::ButtonCode id, bool state);
 
     /**
      * Enable or disable (gray out) the OK button.
@@ -612,11 +616,6 @@ public Q_SLOTS:
      */
     void setHelp(const QString &anchor, const QString &appname = QString());
 
-    /**
-     * Returns the status of the Details button.
-     */
-    bool isDetailsWidgetVisible() const;
-
     /**
      * Sets the status of the Details button.
      */
